/*
 * This file is part of liblcf. Copyright (c) 2017 liblcf authors.
 * https://github.com/EasyRPG/liblcf - https://easyrpg.org
 *
 * liblcf is Free/Libre Open Source Software, released under the MIT License.
 * For the full copyright and license information, please view the COPYING
 * file that was distributed with this source code.
 */

#ifndef LCF_COMMAND_CODES_H
#define LCF_COMMAND_CODES_H

#include "rpg_eventcommand.h"

/**
 * Abbreviate RPG::EventCommand::Code to Cmd.
 */

typedef RPG::EventCommand::Code Cmd;

#endif
