/*
 * This file is part of liblcf. Copyright (c) 2017 liblcf authors.
 * https://github.com/EasyRPG/liblcf - https://easyrpg.org
 *
 * liblcf is Free/Libre Open Source Software, released under the MIT License.
 * For the full copyright and license information, please view the COPYING
 * file that was distributed with this source code.
 */

#ifndef LCF_OPTIONS_H
#define LCF_OPTIONS_H

/*
 * Includes GNU Autotools build configuration parameters.
 * This option may have defined LCF_SUPPORT_XML and others.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

/**
 * Outputs information about read chunks on stdout during parsing
 */
//#define LCF_DEBUG_TRACE

#endif
